@@ -322,7 +322,7 @@ def space(
         controller=controller_model,
         estimator=estimation_model,
         controller_mab_weight=not disable_controller_mab_weight,
-        voters=50
+        voters=n_controllers
     )
 
     execution_time = optimize(
